Thread (4 messages) 4 messages, 3 authors, 2023-05-02

Re: [PATCH] strbuf_stripspace(): rename skip_comments arg to strip_comments

From: Felipe Contreras <hidden>
Date: 2023-05-02 19:01:03

Jeff King wrote:
I'll quote liberally from the original below:

On Thu, Mar 23, 2023 at 05:22:34PM +0100, Oswald Buddenhagen wrote:
quoted
That makes its function much clearer and more consistent with the
context.

Signed-off-by: Oswald Buddenhagen <redacted>
---
 strbuf.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/strbuf.c b/strbuf.c
index 1c57ac6574..49e8beaa4c 100644
--- a/strbuf.c
+++ b/strbuf.c
@@ -1118,10 +1118,10 @@ static size_t cleanup(char *line, size_t len)
  *
  * If last line does not have a newline at the end, one is added.
  *
  * Enable skip_comments to skip every line starting with comment
  * character.
  */
-void strbuf_stripspace(struct strbuf *sb, int skip_comments)
+void strbuf_stripspace(struct strbuf *sb, int strip_comments)
@@ -1118,10 +1118,10 @@ static size_t cleanup(char *line, size_t len)
  * If last line does not have a newline at the end, one is added.
  *
- * Enable skip_comments to skip every line starting with comment
+ * Enable strip_comments to strip every line starting with a comment
  * character.
  */
I don't have a strong opinion either way. The original name was just
copied from stripspace()'s similar parameter, which came from 9690c118fa
(Fix git-stripspace to process correctly long lines and spaces.,
2007-06-25). I don't think it carries any particular significance,
though I find either name easy enough to understand.
To me strip_comments makes more sense, because it implies an active
action, skip_comments implies nothing will be done on them.

-- 
Felipe Contreras
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help